"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Boom = require("boom");
const querystring_1 = require("querystring");
const config_1 = require("../config");
const helpers_1 = require("../helpers");
const matchers_1 = require("../matchers");
const buildUri = (request, version, pathContainsVersion) => {
    const basePath = config_1.config.get("basePath");
    const versionedPath = pathContainsVersion
        ? `${basePath}${request.path.slice(basePath.length - 1)}`
        : `${basePath}v${version}${request.path.slice(basePath.length - 1)}`;
    const method = request.method === "options" ? request.headers["access-control-request-method"] : request.method;
    const route = request.server.match(method, versionedPath);
    if (!route) {
        return;
    }
    if (route.path.indexOf(`${basePath}v${version}/`) === 0) {
        const fullPath = `${basePath}v${version}${request.path.slice(basePath.length - 1)}`;
        const hasQuery = Object.keys(request.query).length > 0;
        request.setUrl(hasQuery ? `${fullPath}?${querystring_1.stringify(request.query)}` : fullPath);
    }
};
exports.onRequest = (request, h) => {
    let pathContainsVersion = false;
    let requestedVersion;
    if (config_1.config.get("strategies.customHeader.enabled")) {
        requestedVersion = matchers_1.matchCustomHeader(request);
    }
    if (!helpers_1.isValid(requestedVersion) && config_1.config.get("strategies.acceptHeader.enabled")) {
        requestedVersion = matchers_1.matchAcceptHeader(request);
    }
    if (!helpers_1.isValid(requestedVersion) && config_1.config.get("strategies.query.enabled")) {
        requestedVersion = matchers_1.matchQuery(request);
    }
    if (!helpers_1.isValid(requestedVersion) && config_1.config.get("strategies.path.enabled")) {
        requestedVersion = matchers_1.matchPath(request);
        if (helpers_1.isValid(requestedVersion)) {
            pathContainsVersion = true;
        }
    }
    if (helpers_1.isValid(requestedVersion) && !config_1.config.get("versions.allowed").includes(requestedVersion)) {
        return Boom.badRequest("The specified API version is not supported.");
    }
    if (!helpers_1.isValid(requestedVersion)) {
        requestedVersion = config_1.config.get("versions.default");
    }
    buildUri(request, requestedVersion, pathContainsVersion);
    request.pre.version = requestedVersion;
    return h.continue;
};
//# sourceMappingURL=request.js.map