"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MediaType = require("media-type");
const config_1 = require("./config");
const helpers_1 = require("./helpers");
function matchQuery(request) {
    return helpers_1.caster(request.query[config_1.config.get("strategies.query.parameter")]);
}
exports.matchQuery = matchQuery;
function matchPath(request) {
    const pattern = new RegExp(config_1.config.get("strategies.path.pattern"));
    const match = pattern.exec(request.path);
    return match && match.length === 2 ? helpers_1.caster(match[1]) : null;
}
exports.matchPath = matchPath;
function matchCustomHeader(request) {
    const strategy = config_1.config.get("strategies.customHeader");
    const versionHeader = request.headers[strategy.parameter];
    const pattern = new RegExp(strategy.pattern);
    return pattern.test(versionHeader) ? helpers_1.caster(versionHeader) : null;
}
exports.matchCustomHeader = matchCustomHeader;
function matchAcceptHeader(request) {
    const standardsTree = config_1.config.get("strategies.acceptHeader.standardsTree");
    const pattern = new RegExp(`^${standardsTree}.[a-z][a-z0-9.!#$&^_-]{0,126}.v[0-9]+$`, "i");
    const media = MediaType.fromString(request.headers.accept);
    if (media.isValid()) {
        const subType = config_1.config.get("strategies.acceptHeader.subType");
        // 1. Check the accept header for IANA compliance
        if (pattern.test(media.subtype)) {
            const vendorFacets = media.subtypeFacets.slice(1, media.subtypeFacets.length - 1);
            const vendorName = vendorFacets.join(".");
            if (vendorName === subType) {
                return helpers_1.caster(media.subtypeFacets[media.subtypeFacets.length - 1].slice(1));
            }
        }
        // 2. Check the header for a version parameter
        const versionParam = media.parameters[config_1.config.get("strategies.acceptHeader.parameter")];
        if (versionParam && media.subtype.includes(subType)) {
            const vendorFacets = media.subtypeFacets.slice(1);
            const vendorName = vendorFacets.join(".");
            if (vendorName === subType) {
                return helpers_1.caster(versionParam);
            }
        }
    }
    return null;
}
exports.matchAcceptHeader = matchAcceptHeader;
//# sourceMappingURL=matchers.js.map